/**
 * Created by John on 7/14/2017.
 */
var moment = require('moment');
var rp = require("request-promise");

function AsnHelper(config) {
    this.config = config;
    this.root = "http://" + config.asn.host + ":" + config.asn.port + config.asn.root;
}

/**
 * Gets ASN data for the UI via Promise
 *
 * @param {Object} req ExpressJS Request
 * @returns {Promise} Web Service call promise
 */
AsnHelper.prototype.getAsnDataPromise = function(req) {
    var url = this.root;
    var options = {
        uri: url,
        method: 'GET',
        headers: {
            'User-Agent': 'fmc (node/' + process.version + ')',
            'Content-Type': 'application/json'
        },
        qs: {
            limit: req.body.limit,
            offset: req.body.offset,
            order: req.body.order,
            where: req.body.where
        },
        json: true,
        resolveWithFullResponse: true
    };
    return (rp(options).promise());
}

/**
 * Patches ASN data for Receipts via Promise
 *
 * @param {Object} req ExpressJS Request
 * @returns {Promise} Web Service call promise
 */
AsnHelper.prototype.getAsnUpdatePromise = function(req) {
    var url = this.root + "/" + req.body.id;
    var options = {
        uri: url,
        method: 'PATCH',
        headers: {
            'User-Agent': 'fmc (node/' + process.version + ')',
            'Content-Type': 'application/json'
        },
        body: req.body,
        json: true,
        resolveWithFullResponse: true
    };
    return (rp(options).promise());
};
/**
 *
 * @param {String} clinic Fresenius clinic id
 * @returns {Promise} Web Service call promise
 */
AsnHelper.prototype.getOpenAsns = function(clinic) {
    var url = this.root;
    var options = {
        uri: url + "/clinic/" + clinic,
        method: 'GET',
        headers: {
            'User-Agent': 'fmc (node/' + process.version + ')',
            'Content-Type': 'application/json'
        },
        json: true,
        resolveWithFullResponse: true
    };
    return (rp(options).promise());
}

module.exports = AsnHelper;

