var moment = require('moment');
var winston = require('winston');
var logger = winston.loggers.get('main');
var path = require("path");
var env         = process.env.NODE_ENV || "prod";
var config      = require(path.join(__dirname,  '..', '/config/config.json'))[env];

module.exports = function(sequelize, DataTypes) {
    var Inventory = sequelize.define('Inventory', {
            id: {
                type: DataTypes.INTEGER,
                field: 'id',
                primaryKey: true,
                autoIncrement: true
            },
            devicePk: {
                type: DataTypes.INTEGER,
                field: 'device_pk'
            },
            deviceId: {
                type: DataTypes.STRING,
                field: 'device_id'
            },
            type: {
                type: DataTypes.STRING,
                field: 'type'
            },
            timestamp: {
                type: DataTypes.DATE(3),
                field: 'time_stamp',
                set: function(val) {
                    if (val == null) {
                        this.setDataValue('timestamp', null);
                    } else {
                        try {
                            var m = moment(val, "YYYY-MM-DDTHH:mm:ss.SSSZ");
                            if ( !m.isValid() ) {
                                m = moment(val, "YYYY-MM-DD HH:mm:ss.SSS" );
                                if (!m.isValid()) {
                                    logger.warn("Invalid Timestamp: " + val);
                                    var mom = moment();
                                    this.setDataValue('timestamp', mom);
                                } else {
                                    this.setDataValue('timestamp', m)
                                }
                            } else {
                                this.setDataValue('timestamp', m)
                            }
                        } catch (e) {
                            this.setDataValue('timestamp', null);
                        }
                    }
                }
            },
            userId: {
                type: DataTypes.STRING,
                field: 'user_id'
            },
            clinicId: {
                type: DataTypes.STRING,
                field: 'clinic_id'
            },
            consumerId: {
                type: DataTypes.STRING,
                field: 'consumer_id'
            },
            vendorMaterial: {
                type: DataTypes.STRING,
                field: 'vendor_material'
            },
            count: {
                type: DataTypes.INTEGER,
                field: 'count'
            },
            poPrefix: {
                type: DataTypes.STRING,
                field: 'po_prefix'
            },
            poNumber: {
                type: DataTypes.STRING,
                field: 'po_number'
            },
            description: {
                type: DataTypes.STRING,
                field: 'description'
            },
            countType: {
                type: DataTypes.STRING,
                field: 'count_type'
            },
            catType: {
                type: DataTypes.STRING,
                field: 'count_type'
            },
            sapMaterial: {
                type: DataTypes.STRING,
                field: 'sap_material'
            },
            lot: {
                type: DataTypes.STRING,
                field: 'lot'
            },
            expiration: {
                type: DataTypes.DATE,
                field: 'expiration',
                set: function(val) {
                    if (val == null) {
                        this.setDataValue('expiration', null);
                    } else {
                        try {
                            var m = moment(val, "YYYY-MM-DDTHH:mm:ss.SSSZ");
                            if (!m.isValid()) {
                                m = moment(val, "YYYY-MM-DD HH:mm:ss.SSS");
                                if (!m.isValid()) {
                                    logger.debug("Invalid Expiration: " + val);
                                    this.setDataValue('expiration', null);
                                } else {
                                    this.setDataValue('expiration', m);
                                }
                            } else {
                                this.setDataValue('expiration', m);
                            }
                        } catch (e) {
                            this.setDataValue('expiration', null);
                        }
                    }
                }
            },
            cntInd: {
                type: DataTypes.BOOLEAN,
                field: 'cnt_ind'
            },
            asnId: {
                type: DataTypes.INTEGER,
                field: "asn_id",
                defaultValue: null
            },
            modifiedBy: {
                type: DataTypes.STRING,
                field: "modified_by"
            },
            modifiedDate: {
                type: DataTypes.DATE,
                field: "date_modified",
                set: function(val) {
                    if (val == null) {
                        this.setDataValue('modifiedDate', null);
                    } else {
                        try {
                            var m = moment(val, "YYYY-MM-DDTHH:mm:ss.SSSZ");
                            if (!m.isValid()) {
                                m = moment(val, "YYYY-MM-DD HH:mm:ss.SSS");
                                if (!m.isValid()) {
                                    logger.debug("Invalid Expiration: " + val);
                                    this.setDataValue('modifiedDate', null);
                                } else {
                                    this.setDataValue('modifiedDate', m);
                                }
                            } else {
                                this.setDataValue('modifiedDate', m);
                            }
                        } catch (e) {
                            this.setDataValue('modifiedDate', null);
                        }
                    }
                }
            },
            sapFlag: {
                type: DataTypes.BOOLEAN,
                field: 'sap_flag',
                defaultValue: false
            }
        },
        {
            timestamps: true,
            createdAt: false,
            updatedAt: 'date_modified',
            deletedAt: false,
            tableName: 'tbl_inventory',
            indexes: [
                // Create a unique index on device timestamp
                {
                    unique: true,
                    fields: ['deviceId','timestamp']
                },
            ]
        }


    );
    if (config.dialect === "mssql") {
        Inventory.hook('afterCreate', function (inv, options) {
            if (inv.asnId) {
                sequelize
                    .query('EXEC [db_owner].[prc_insert_asn] :id, :asnId, :qty',
                        {replacements: {id: inv.id, asnId: inv.asnId, qty: inv.count}, transaction: options.transaction})
                    .then(function (v) {
                        console.log(v)
                    })
                    .catch(function (err) {
                        console.error(err)
                    });
            }
        });
        Inventory.hook('afterUpdate', function (inv, options) {
            if (inv.asnId) {
                sequelize
                    .query('EXEC [db_owner].[prc_update_asn] :id, :asnId',
                        {replacements: {id: inv.id, asnId: inv.asnId}, transaction: options.transaction})
                    .then(function (v) {
                        console.log(v)
                    })
                    .catch(function (err) {
                        console.error(err)
                    });
            }
        });
    }
    var InventoryASN = require("./inventoryAsn")(sequelize, DataTypes);
    Inventory.hasOne(InventoryASN, { as: 'ASN', foreignKey: 'inventory_id' });
    return Inventory;
};
