/**
 * Created by will on 10/13/15.
 */

angular.module('app.constants', [])
    .filter('stripChars', function() {
        return function(value) {
            if (value != null) {
                var type = typeof value;
                if (type == 'number') {
                    value = "" + value;
                }
                var result = value.replace(/[^0-9]/g, '');
                return result;
            }
            else
                return "";
        }
    })
    .filter('clinicFilter', function() {
        return function(value) {
            if (value != null) {
                var type = typeof value;
                if (type == 'number') {
                    value = "" + value;
                }
                //var result = value.replace(/[^0-9]/g, '');
                //return result;
                return value;
            }
            else
                return "";
        }
    })
    .filter('passwordFilter', function() {
        return function(value) {
            return "-HIDDEN-";
        }
    })
    .filter('recQtyFilter', function() {
        return function(value) {
            if (value === -1) return "";
            return value;
        }
    })
    .filter('userTypeFilter', function() {
        return function (value) {
            if (value != null) {
                switch(value) {
                    case 2: {
                        return "Admin";
                    }
                    case 1: {
                        return "User";
                    }
                    default: {
                        return "Disabled";
                    }
                }
            }
        }
    })
    .filter('messageFilter', function() {
        return function (value) {
            if (value != null) {
               return value;
            }
        }
    })
    .filter('recipientFilter', function() {
        return function (value) {
            if (value != null) {
                if (Array.isArray(value)) {
                    var out = "";

                    for (var r = 0; r < value.length; r++) {
                        var recip = value[r];
                        out += ((r == 0) ? "" : ", ") + recip.clinic.clinicId;
                    }

                    return out;
                }
                else
                    return value.recipients.clinic.clinicId
            }
        }
    })
    .filter('catalogFilter', function() {
        return function (value) {
            if (value != null) {
                if (Array.isArray(value)) {
                    var out = "";

                    for (var r = 0; r < value.length; r++) {
                        var cat = value[r];
                        out += ((r == 0) ? "" : ", ") + cat.vendorId;
                    }

                    return out;
                }
                else
                    return value.vendorId
            }
        }
    })
    .filter('createdByFilter', function() {
        return function (value) {
            if (value != null) {
                return value.createdBy.displayName
            }
        }
    })
    .factory('Constants', ['GridService', 'uiGridConstants', function(GridService, uiGridConstants) {
        return {
            getDefaultGridOptions: function() {
                var options = {
                    rowHeight: 40,
                    enableSorting: true,
                    enableColumnMenus: false,
                    paginationPageSizes: [50, 100],
                    paginationPageSize: 50,
                    enableFiltering: true
                };
                return options;
            },
            clinicProfileCols: [
                {
                    field: 'clinicId',
                    displayName: 'CLINIC ID',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'clinicFilter'
                },
                {
                    field: 'vendorList',
                    displayName: 'CATALOGS',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'mirceraVisible',
                    displayName: 'MIRCERA VISI',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'mirceraIo',
                    displayName: 'MIRCERA IO',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'areanespVisible',
                    displayName: 'ARANESP VISI',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'areanespIo',
                    displayName: 'ARANESP IO',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'epogenVisible',
                    displayName: 'EPOGEN VISI',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'epogenIo',
                    displayName: 'EPOGEN IO',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'retacritVisible',
                    displayName: 'RETACRIT VISI',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'retacritIo',
                    displayName: 'RETACRIT IO',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'countInEach',
                    displayName: 'COUNT IN EACH',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'dateModified',
                    displayName: 'DATE MODIFIED',
                    width: '9%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'date:\'MM-dd-yyyy\'',
                    sort: {
                        direction: uiGridConstants.DESC,
                        priority: 0
                    }
                },
                {
                    field: 'actions',
                    displayName: 'ACTIONS',
                    enableFiltering: false,
                    enableSorting: false,
                    cellTemplate: '<div class="ui-grid-cell-contents">' +
                        '<span ng-click="grid.appScope.countModal(row)" class="editButton" title="Preview Counts"><i class="fa fa-tablet"></i></span>' +
                        '<span ng-click="grid.appScope.addRowModal(row)" class="editButton" title="Edit Clinic"><i class="ion-edit"></i></span>' +
                        '<span ng-click="grid.appScope.deleteRow(row)" class="deleteButton" title="Delete Clinic"><i class="ion-ios-trash"></i></span>' +
                        '</div>',
                    width: '10%'
                }
            ],
            masterItemCols: [
                {
                    field: 'sapMaterial',
                    displayName: 'SAP MATERIAL',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'description',
                    displayName: 'MATERIAL DESCRIPTION',
                    width: '21%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'cntInd',
                    displayName: 'CNT IND',
                    width: '5%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'cntDescription',
                    displayName: 'CNT DESCRIPTION',
                    width: '9%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'catalogAsString',
                    displayName: 'CATALOGS',
                    width: '13%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted /*,
                    cellFilter: 'catalogFilter' */
                },
                {
                    field: 'vendorMaterial',
                    displayName: 'VENDOR MATERIAL',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'conv',
                    displayName: 'CONV',
                    width: '5%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'countType',
                    displayName: 'COUNT TYPE',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'dateModified',
                    displayName: 'DATE MODIFIED',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'date:\'MM-dd-yyyy\'',
                    sort: {
                        direction: uiGridConstants.DESC,
                        priority: 0
                    }
                },
                {
                    field: 'messaging',
                    displayName: 'MESSAGES',
                    width: '8%',
                    enableFiltering: false,
                    visible: true,
                    cellTooltip: true,
                    headerTooltip: true,
                    cellTemplate: '<div class="ui-grid-cell-contents">' +
                    '<div ng-show="row.entity.alternates" title="{{(row.entity.cntInd || row.entity.countType) ? \'[Ignored] \' + row.entity.alternates : row.entity.alternates}}" style="display:inline; float:left;"><i class="ion-arrow-swap  font-large {{(row.entity.cntInd || row.entity.countType) ? \'red\' : \'\'"></i></div>' +
                    '<div ng-show="row.entity.alternates && row.entity.message" style="display:inline; float:left;">&nbsp;&nbsp;&nbsp;&nbsp;</div>' +
                    '<div ng-show="row.entity.message" title="{{(row.entity.cntInd || row.entity.countType) ? \'[Ignored] \' + row.entity.message : row.entity.message}}" style="display:inline; float:left;"><i class="ion-ios-chatbubble font-larger {{(row.entity.cntInd || row.entity.countType) ? \'red\' : \'\'}}"></i></div>' +
                    '</div>',
                },
                {
                    field: 'showInventoryInd',
                    displayName: 'On Hand Inventory',
                    width: '5%',
                    visible: false,
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'actions',
                    displayName: 'ACTIONS',
                    enableFiltering: false,
                    enableSorting: false,
                    cellTemplate: '<div class="ui-grid-cell-contents">' +
                        '<div ng-click="grid.appScope.addRowModal(row)" class="editButton" title="Edit Item"><i class="ion-edit"></i></div>' +
                        '<div ng-click="grid.appScope.deleteRow(row)" class="deleteButton" title="Deactivate Item"><i class="ion-ios-trash"></i></div>' +
                        '</div>',
                    width: '8%'
                }
            ],
            countDataCols: [
                {
                    field: 'timestamp',
                    displayName: 'TIME STAMP',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'date:\'MM-dd-yyyy\'',
                    enableFiltering: false,
                    sort: {
                        direction: uiGridConstants.DESC,
                        priority: 0
                    }
                },
                {
                    field: 'clinicId',
                    displayName: 'CLINIC ID',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'stripChars'
                },
                {
                    field: 'sapMaterial',
                    displayName: 'SAP MATERIAL',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorMaterial',
                    displayName: 'VENDOR MATERIAL',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'description',
                    displayName: 'DESCRIPTION',
                    width: '24%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'count',
                    displayName: 'COUNT',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'countType',
                    displayName: 'COUNT TYPE',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'catType',
                    displayName: 'CAT TYPE',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                }
            ],
            consumptionCols: [
                {
                    field: 'timestamp',
                    displayName: 'TIME STAMP',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'date:\'MM-dd-yyyy\'',
                    sort: {
                        direction: uiGridConstants.DESC,
                        priority: 0
                    }
                },
                {
                    field: 'clinicId',
                    displayName: 'CLINIC ID',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'clinicFilter'
                },
                {
                    field: 'userId',
                    displayName: 'USER ID',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'clinicFilter'
                },
                {
                    field: 'sapMaterial',
                    displayName: 'SAP MATERIAL',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorMaterial',
                    displayName: 'VENDOR MATERIAL',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'description',
                    displayName: 'DESCRIPTION',
                    width: '24%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'count',
                    displayName: 'COUNT',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'lot',
                    displayName: 'LOT',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'expiration',
                    displayName: 'EXPIRATION',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    cellFilter: 'date:\'MM / yy\'',
                    headerCellClass: GridService.sorted
                }
            ],
            inventoryCols: [
                {
                    field: 'timestamp',
                    displayName: 'TIME STAMP',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'date:\'MM-dd-yyyy\'',
                    enableFiltering: false,
                    sort: {
                        direction: uiGridConstants.DESC,
                        priority: 0
                    }
                },
                {
                    field: 'clinicId',
                    displayName: 'CLINIC ID',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'clinicFilter'
                },
                {
                    field: 'userId',
                    displayName: 'USER ID',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'clinicFilter'
                },
                {
                    field: 'sapMaterial',
                    displayName: 'SAP MATERIAL',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorMaterial',
                    displayName: 'VENDOR MATERIAL',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'description',
                    displayName: 'DESCRIPTION',
                    width: '24%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'count',
                    displayName: 'COUNT',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'lot',
                    displayName: 'LOT',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'expiration',
                    displayName: 'EXPIRATION',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    cellFilter: 'date:\'MM / yy\'',
                    headerCellClass: GridService.sorted
                }
            ],
            receiptCols: [
                {
                    field: 'timestamp',
                    displayName: 'TIME STAMP',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'date:\'MM-dd-yyyy\'',
                    enableFiltering: false,
                    sort: {
                        direction: uiGridConstants.DESC,
                        priority: 0
                    }
                },
                {
                    field: 'clinicId',
                    displayName: 'CLINIC ID',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'clinicFilter'
                },
                {
                    field: 'sapMaterial',
                    displayName: 'SAP MATERIAL',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorMaterial',
                    displayName: 'VENDOR MATERIAL',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'description',
                    displayName: 'DESCRIPTION',
                    width: '16%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'count',
                    displayName: 'QTY',
                    width: '5%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'poPrefix',
                    displayName: 'PO PREFIX',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'poNumber',
                    displayName: 'PO NUMBER',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'lot',
                    displayName: 'LOT',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'expiration',
                    displayName: 'EXPIRATION',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    cellFilter: 'date:\'MM / yy\'',
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'actions',
                    displayName: 'ACTIONS',
                    enableFiltering: false,
                    enableSorting: false,
                    cellTemplate: '<div class="ui-grid-cell-contents">' +
                    '<div ng-show="!row.entity.sapFlag" ng-click="grid.appScope.addRowModal(row)" class="editButton" title="Edit Qty"><i class="ion-edit"></i></div>' +
                    '</div>',
                    width: '8%'
                }
            ],
            purchaseOrderCols: [
                {
                    field: 'timestamp',
                    displayName: 'TIME STAMP',
                    width: '20%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'date:\'MM-dd-yyyy\'',
                    sort: {
                        direction: uiGridConstants.DESC,
                        priority: 0
                    }
                },
                {
                    field: 'clinicId',
                    displayName: 'CLINIC ID',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'clinicFilter'
                },
                {
                    field: 'userId',
                    displayName: 'USER ID',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'sapMaterial',
                    displayName: 'SAP MATERIAL',
                    width: '16%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorMaterial',
                    displayName: 'VENDOR MATERIAL',
                    width: '16%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'description',
                    displayName: 'DESCRIPTION',
                    width: '19%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'count',
                    displayName: 'COUNT',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                }
            ],
            userCols: [
                {
                    field: 'username',
                    displayName: 'USER ID',
                    width: '35%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'password',
                    displayName: 'PASSWORD',
                    width: '20%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'passwordFilter'
                },
                {
                    field: 'type',
                    displayName: 'TYPE',
                    width: '20%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'userTypeFilter'
                },
                {
                    field: 'actions',
                    displayName: 'ACTIONS',
                    enableFiltering: false,
                    enableSorting: false,
                    cellTemplate: '<div class="ui-grid-cell-contents">' +
                    '<div ng-click="grid.appScope.addRowModal(row)" class="editButton" title="Edit User"><i class="ion-edit"></i></div>' +
                    '<div ng-click="grid.appScope.deleteRow(row)" class="deleteButton" title="Deactivate User"><i class="ion-ios-trash"></i></div>' +
                    '</div>',
                    width: '25%'
                }
            ],
            ftpCols: [
                {
                    field: 'deviceId',
                    displayName: 'DEVICE ID',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'userId',
                    displayName: 'USER',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'message',
                    displayName: 'MESSAGE',
                    width: '33%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'sent',
                    displayName: 'WHEN',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: "date:'MM-dd-yyyy'",
                },
                {
                    field: 'success',
                    displayName: 'SUCCESSFUL?',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'errorMessage',
                    displayName: 'ERROR MSG',
                    width: '25%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'actions',
                    displayName: 'ACTIONS',
                    enableFiltering: false,
                    enableSorting: false,
                    cellTemplate: '<div class="ui-grid-cell-contents">' +
                    '<div ng-click="grid.appScope.addRowModal(row)" class="editButton" title="View Detail"><i class="ion-edit"></i></div>' +
                    '</div>',
                    width: '5%'
                }
            ],
            vendorCols: [
                {
                    field: 'vendorId',
                    displayName: 'SAP ID',
                    width: '25%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorDisplay',
                    displayName: 'DISPLAY NAME',
                    width: '25%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'minimumOrderAmount',
                    displayName: 'MINIMUM ORDER',
                    width: '13%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'fee',
                    displayName: 'FEE',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'actions',
                    displayName: 'ACTIONS',
                    enableFiltering: false,
                    enableSorting: false,
                    cellTemplate: '<div class="ui-grid-cell-contents" data-ng-controller="BaseCtrl" ng-show="isAdmin()">' +
                    '<div ng-click="grid.appScope.addRowModal(row)" class="editButton" title="Edit Vendor" ><i class="ion-edit"></i></div>' +
                    '<div ng-click="grid.appScope.deleteRow(row)" class="deleteButton" title="Delete Vendor" ><i class="ion-ios-trash"></i></div>' +
                    '</div>',
                    width: '25%'
                }
            ],
            vendorRouteCols: [
                {
                    field: 'vendorId',
                    displayName: 'SAP ID',
                    width: '25%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorDisplay',
                    displayName: 'DISPLAY NAME',
                    width: '25%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorPathRoute',
                    displayName: 'ROUTE',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'actions',
                    displayName: 'ACTIONS',
                    enableFiltering: false,
                    enableSorting: false,
                    cellTemplate: '<div class="ui-grid-cell-contents" data-ng-controller="BaseCtrl" ng-show="isAdmin()">' +
                        '<div ng-click="grid.appScope.addRowModal(row)" class="editButton" title="Edit Vendor" ><i class="ion-edit"></i></div>' +
//                        '<div ng-click="grid.appScope.deleteRow(row)" class="deleteButton" title="Delete Vendor"><i class="ion-ios-trash"></i></div>' +
                        '</div>',
                    width: '40%'
                }
            ],
            vendorRouteClinicCols: [
                {
                    field: 'clinicId',
                    displayName: 'CLINIC ID',
                    width: '20%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'clinicFilter'
                },
                {
                    field: 'vendorId',
                    displayName: 'SAP ID',
                    width: '20%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorDisplay',
                    displayName: 'DISPLAY NAME',
                    width: '20%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorPathRoute',
                    displayName: 'ROUTE',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'actions',
                    displayName: 'ACTIONS',
                    enableFiltering: false,
                    enableSorting: false,
                    cellTemplate: '<div class="ui-grid-cell-contents" data-ng-controller="BaseCtrl" ng-show="isAdmin()">' +
                        '<div ng-click="grid.appScope.addRowModal(row)" class="editButton" title="Edit route" ><i class="ion-edit"></i></div>' +
                        '<div ng-click="grid.appScope.deleteRow(row)" class="deleteButton" title="Delete Route"><i class="ion-ios-trash"></i></div>' +
                        '</div>',
                    width: '40%'
                }
            ],
            vendorParCols: [
                {
                    field: 'vendorMaterial',
                    displayName: 'VENDOR MATERIAL ID',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorId',
                    displayName: 'SAP ID',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'clinicId',
                    displayName: 'CLINIC ID',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorDisplay',
                    displayName: 'DISPLAY NAME',
                    width: '20%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'description',
                    displayName: 'MATERIAL DESCRIPTION',
                    width: '20%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'minParValue',
                    displayName: 'MIN PAR VALUE',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'maxParValue',
                    displayName: 'MAX PAR VALUE',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'qohValue',
                    displayName: 'QOH VALUE',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'actions',
                    displayName: 'ACTIONS',
                    enableFiltering: false,
                    enableSorting: false,
                    cellTemplate: '<div class="ui-grid-cell-contents">' +
                        '<div ng-click="grid.appScope.addRowModal(row)" class="editButton" title="Edit Vendor"><i class="ion-edit"></i></div>' +
                        '<div ng-click="grid.appScope.deleteRow(row)" class="deleteButton" title="Delete Vendor"><i class="ion-ios-trash"></i></div>' +
                        '</div>',
                    width: '29%'
                }
            ],
            catalogCols: [
                {
                    field: 'catalogId',
                    displayName: 'NAME',
                    width: '60%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'isDefault',
                    displayName: 'ASSIGN TO ALL?',
                    width: '15%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'actions',
                    displayName: 'ACTIONS',
                    enableFiltering: false,
                    enableSorting: false,
                    cellTemplate: '<div class="ui-grid-cell-contents">' +
                    '<div ng-click="grid.appScope.addRowModal(row)" class="editButton" title="Edit Vendor"><i class="ion-edit"></i></div>' +
                    '<div ng-click="grid.appScope.deleteRow(row)" class="deleteButton" title="Delete Vendor"><i class="ion-ios-trash"></i></div>' +
                    '</div>',
                    width: '25%'
                }
            ],
            messageCols: [
                {
                    field: 'timestamp',
                    displayName: 'CREATED',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'date:\'MM-dd-yyyy\'',
                    enableFiltering: false,
                    sort: {
                        direction: uiGridConstants.DESC,
                        priority: 0
                    }
                },
                {
                    field: 'createdBy.displayName',
                    displayName: 'AUTHOR',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true
                },
                {
                    field: 'recurrenceType',
                    displayName: 'TYPE',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true
                },
                {
                    field: 'message',
                    displayName: 'MESSAGE',
                    width: '40%',
                    cellTooltip: true,
                    headerTooltip: true,
                    cellFilter: 'messageFilter'
                },
                {
                    field: 'recipientsAsString',
                    displayName: 'RECIPIENTS',
                    width: '20%',
                    cellTooltip: true,
                    headerTooltip: true/*,
                    cellFilter: 'recipientFilter'*/
                },
                {
                    field: 'actions',
                    displayName: 'ACTIONS',
                    enableFiltering: false,
                    enableSorting: false,
                    cellTemplate: '<div class="ui-grid-cell-contents">' +
                    '<div ng-click="grid.appScope.addRowModal(row)" class="editButton" title="Edit Message"><i class="ion-edit"></i></div>' +
                    '<div ng-click="grid.appScope.deleteRow(row)" class="deleteButton" title="Delete Message"><i class="ion-ios-trash"></i></div>' +
                    '</div>',
                    width: '15%'
                }
            ],
            ndcDataCols: [
                {
                    field: 'timestamp',
                    displayName: 'TIME STAMP',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'date:\'MM-dd-yyyy\'',
                    enableFiltering: false,
                    sort: {
                        direction: uiGridConstants.DESC,
                        priority: 0
                    }
                },
                {
                    field: 'clinicId',
                    displayName: 'CLINIC ID',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'stripChars'
                },
                {
                    field: 'sapMaterial',
                    displayName: 'SAP MATERIAL',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorMaterial',
                    displayName: 'VENDOR MATERIAL',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'description',
                    displayName: 'DESCRIPTION',
                    width: '22%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'ndc',
                    displayName: 'NDC',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'ndcScanned',
                    displayName: 'NDC SCANNED',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'mrnScanned',
                    displayName: 'MRN SCANNED',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'qty',
                    displayName: 'QTY',
                    width: '6%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                }
            ],
            activityLogCols: [
                {
                    field: 'userId',
                    displayName: 'USER',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'nameTable',
                    displayName: 'TABLE ACCESSED',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'description',
                    displayName: 'DESC',
                    width: '40%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: "date:'MM-dd-yyyy'",
                },
                {
                    field: 'modified',
                    displayName: 'DATE',
                    width: '15%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                }
//                {
//                    field: 'actions',
//                    displayName: 'ACTIONS',
//                    enableFiltering: false,
//                    enableSorting: false,
//                    cellTemplate: '<div class="ui-grid-cell-contents">' +
//                        '<div ng-click="grid.appScope.addRowModal(row)" class="editButton" title="View Detail"><i class="ion-edit"></i></div>' +
//                        '</div>',
//                    width: '5%'
//                }
            ],
            asnCols: [
                {
                    field: 'asnDate',
                    displayName: 'TIME STAMP',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'date:\'MM-dd-yyyy\'',
                    enableFiltering: false,
                    sort: {
                        direction: uiGridConstants.DESC,
                        priority: 0
                    }
                },
                {
                    field: 'clinicId',
                    displayName: 'CLINIC ID',
                    width: '8%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'poNumber',
                    displayName: 'PO',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'lineNumber',
                    displayName: 'LINE',
                    width: '5%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'vendorItemId',
                    displayName: 'VENDOR MATERIAL',
                    width: '11%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'description',
                    displayName: 'DESCRIPTION',
                    width: '20%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'ndc',
                    displayName: 'NDC',
                    width: '10%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'trackingId',
                    displayName: 'TRACKING #',
                    width: '12%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'shipQty',
                    displayName: 'SHIP QTY',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted
                },
                {
                    field: 'receivedQty',
                    displayName: 'REC QTY',
                    width: '7%',
                    cellTooltip: true,
                    headerTooltip: true,
                    headerCellClass: GridService.sorted,
                    cellFilter: 'recQtyFilter'
                }
            ]
        }
    }]);