/**
 * Created by John on 7/21/2016.
 * Modified by TFG on 10/03/2019.
 * Modified by TFG on 11/20/2019.
 * Modified by TFG on 05/21/2020 .
 */
angular.module('app').controller('VendorCtrl', [
    '$scope',
    '$window',
    '$http',
    'uiGridConstants',
    'Constants',
    'ngDialog',
    '$timeout',
    'FileSaver',
    'Blob',

    function($scope, $window, $http, uiGridConstants, Constants, ngDialog, $timeout, FileSaver, Blob) {
        var requestData = {};
        var existingRow = {};
        var recordEdited = false;   // FRES-128 - flag to discrimintate between adding and editing

        $scope.loading = {
            message: 'Loading Data...',
            backdrop: true,
            busyPromise: null
        }

        $scope.savingData = {
            message: 'Saving Data...',
            backdrop: true,
            busyPromise: null
        };

        $scope.busy = {
            message: 'Please wait...',
            backdrop: true,
            busyPromise: null
        };

        $scope.addActivityLog = {
            message: 'Add activity log...',
            backdrop: true,
            busyPromise: null
        };

        $scope.gridOptions = Constants.getDefaultGridOptions();
        $scope.gridOptions.columnDefs = Constants.vendorCols;
        $scope.gridOptions.onRegisterApi = function(gridApi) {
            $scope.gridApi = gridApi;
        };
        $scope.gridOptions.totalItems = 0;

        function getPage() {
            return $http.post('/api/getVendorList', requestData)
                .then(function(res){
                    $scope.gridOptions.data = null;
                    $scope.gridOptions.data = res.data;
                },function(err) {
                    $scope.gridOptions.data = null;
                    console.log("NO REFRESH!!!!" + err);
                });
        }

        $scope.isDisabled = false;
        $scope.showVendorVerifyAlert = false;

        $scope.loading.busyPromise = getPage();

        $scope.digits = {};

        //initializing date picker
        $scope.dateDbA = moment();
        $scope.dateDbB = moment();

        $scope.optionsDbA = {
            callback: fromUpdated
        };
        $scope.optionsDbB = {
            callback: toUpdated
        };
        $scope.menuOpened = false;

        $scope.toggleMenu = function(event) {
            $scope.menuOpened = !($scope.menuOpened);
            event.stopPropagation();
        };

        $scope.closeThis = function() {
            if ($scope.menuOpened) {
                $scope.menuOpened = false;
            }
        };

        function openEditDialog() {
            //Using editVendor as a bindable Object in the modal.... cloning the original Vendor list
            //$scope.editVendor = angular.copy($scope.vendorList);
            ngDialog.open({
                template: '/vendor/vendorMaintenance.html',
                showClose: true,
                scope: $scope
            });
        }

        $scope.addRowModal = function (row) {
            $scope.editRow = { isDefault: false };
            if (row != null) {
                $scope.editRow = findById($scope.gridOptions.data, row.entity.id);
            }
            openEditDialog();
        };

        $scope.deleteRow = function(row) {
            if (row != null) {
                var doDelete = $window.confirm("Are you sure?");
                if (doDelete) {
                    $scope.loading.busyPromise = $http.post('/api/deleteVendor', row.entity).then(function (res) {
                        // FRES-128 - add entry in the activity log
                        $scope.addActivityLog.busyPromise = addActivityLogEntry('tbl_vendor_list', 'removed record [' +
                            row.entity.vendorId + "]");

                        $scope.loading.busyPromise = getPage();
                    });

                    // FRES-112
                    syncAndRebuidVendorRouteTable();
                }
            }
        };


        $scope.saveVendor = function(row) {
            $scope.editRow.dateModified = new Date();
            $scope.savingData.busyPromise = $http.post('/api/saveVendor', $scope.editRow)
                .then(function(res) {
                    // FRES-128 - add entry in the activity log
                    var msg = recordEdited === false ? "added record [" : "modified record [";
                    $scope.addActivityLog.busyPromise = addActivityLogEntry('tbl_vendor_list', msg +
                        $scope.editRow.vendorId + "]");
                    recordEdited = false;       // Reset flag add/edit

                    $scope.closeDialog();
                    $scope.loading.busyPromise = getPage();

                    // FRES-112
                    syncAndRebuidVendorRouteTable();

                }, function(err) {
                    console.log("error: " + err);
                    recordEdited = false;       // Reset flag add/edit
                    $scope.closeDialog();
                    $scope.loading.busyPromise = getPage();
                });
        };

        $scope.verifyVendor = function() {
            console.log("verifying");
            var row = {};
            row.vendorId = $scope.editRow.vendorId;
            //query for the combo
            $http.post('/api/getVendor', row)
                .then(function(res) {
                    if (res.data[0] != null) {
                        existingRow = res.data[0];
                        if (existingRow.vendorId != null && existingRow.vendorId == row.vendorId) {
                            $scope.showVendorVerifyAlert = true;
                            recordEdited = true;       // Set flag add/edit
                        }
                    } else {
                        $scope.isDisabled = true;
                    }
                }, function(err) {
                    console.log("Error checking Vendor : " + err);
                    $scope.closeDialog();
                });
        };

        $scope.editExistingRow = function() {
            $scope.editRow = existingRow;
            $scope.showVendorVerifyAlert = false;
            $scope.isDisabled = true;
        };

        $scope.closeDialog = function(){
            ngDialog.close();
            $scope.showVendorVerifyAlert = false;
            $scope.isDisabled = false;
        };

        function findById(array, value) {
            for (var i = 0; i < array.length; i++) {
                if (array[i]['id'] === value) {
                    return array[i];
                }
            }
            return null;
        }

        function fromUpdated(date) {
            if (requestData.where == null) {
                requestData.where = {};
            }
            if (requestData.where.dateModified == null) {
                requestData.where.dateModified = {};
            }

            requestData.where.dateModified['$gt'] = date.startOf('day');
            $scope.fromDate = date.format("MM-DD-YYYY");
            getPage();
        }

        function toUpdated(date) {
            if (requestData.where == null) {
                requestData.where = {};
            }
            if (requestData.where.dateModified == null) {
                requestData.where.dateModified = {};
            }

            requestData.where.dateModified['$lt'] = date.endOf('day');
            $scope.toDate = date.format("MM-DD-YYYY");
            getPage();
        }

        // FRES-112
        // Function to sync tbl_vendor_list with tbl_vendor_route and then rebuild the tbl_vendor_route_app, the
        // table sent to the terminal.
        // The function is called everytime a new record is added to the tbl_vendor_list or when a record is
        // removed from the tbl_vendor_list
        // NOTE ! The function uses a dialog from the vendor page to notify errors or the sync completion
        function syncAndRebuidVendorRouteTable() {
            var delayInMilliseconds = 2500; //2.5 second

            // Delay the call to give time to the previous activity log to be stored

            setTimeout(function() {
                $http.post('/api/v1/syncVendorRouteTables', null)
                    .then(function(res) {
                        console.log("Called the sync vendor route tables API function - OK");
                        // Now rebuild new architecture table
                        $http.post('/api/v1/rebuildVendorRouteAppTable', null)
                            .then(function(res) {
                                console.log("Called the rebuild vendor route app tables API function - OK");

                                // FRES-128 - add entry in the activity log
                                $scope.addActivityLog.busyPromise = addActivityLogEntry('tbl_vendor_route_app', 're-done the sync');

                                ngDialog.open({
                                    template: '/vendor/vendorConfirm.html',
                                    showClose: true,
                                    scope: $scope
                                });
                            }, function(err) {
                                console.log("Error checking Vendor tables : " + err);
                                ngDialog.open({
                                    template: '/vendor/vendorError.html',
                                    showClose: true,
                                    scope: $scope
                                });
                            });

                        // Now rebuild OLD archtecture table
                        $http.post('/api/v1/rebuildVendorRouteProductTable', null)
                            .then(function(res) {
                                console.log("Called the rebuild vendor route app tables API function - OK");

                                // FRES-128 - add entry in the activity log
                                $scope.addActivityLog.busyPromise = addActivityLogEntry('tbl_vendor_route_app', 're-done the sync');

                                ngDialog.open({
                                    template: '/vendor/vendorConfirm.html',
                                    showClose: true,
                                    scope: $scope
                                });
                            }, function(err) {
                                console.log("Error checking Vendor tables : " + err);
                                ngDialog.open({
                                    template: '/vendor/vendorError.html',
                                    showClose: true,
                                    scope: $scope
                                });
                            });

                    }, function(err) {
                        ngDialog.open({
                            template: '/vendor/vendorError.html',
                            showClose: true,
                            scope: $scope
                        });
                        console.log("Error checking Vendor tables : " + err);
                    });
            }, delayInMilliseconds);
        }

        // FRES-128 - add entry to the ActivityLog table
        // Important ! Give at least a couple of seconds if you need to call this function back-to-back
        function addActivityLogEntry(name_table, desc)  {
            console.log("vendorCtrl.js - addActivityLogEntry : " + name_table + " - " + desc);
            var record = {nameTable:"", description:"", dateModified:0};
            record.dateModified = new Date();
            record.nameTable = name_table;
            record.description = desc;

            return $http.post('/api/recordActivityLog', record).then(function (res) {
                console.log("log recorded");
            }, function (err) {
                console.log("error: " + err);
            });
        }
    }
]);