/**
 * Created by TFG on 9/16/2019.
 * Modified by TFG on 5/21/2020 .
 */
angular.module('app').controller('VendorRouteCtrl', [
    '$scope',
    '$window',
    '$http',
    'uiGridConstants',
    'Constants',
    'ngDialog',
    '$timeout',
    'FileSaver',
    'Blob',

    function($scope, $window, $http, uiGridConstants, Constants, ngDialog, $timeout, FileSaver, Blob) {
        var requestData = {};
        var requestExtraData = {};
        var existingRow = {};

        $scope.loading = {
            message: 'Loading Data...',
            backdrop: true,
            busyPromise: null
        }

        $scope.savingData = {
            message: 'Saving Data...',
            backdrop: true,
            busyPromise: null
        };

        $scope.busy = {
            message: 'Please wait...',
            backdrop: true,
            busyPromise: null
        };

        $scope.addActivityLog = {
            message: 'Add activity log...',
            backdrop: true,
            busyPromise: null
        };

        $scope.gridOptions = Constants.getDefaultGridOptions();
        $scope.gridOptions.columnDefs = Constants.vendorRouteCols;
        $scope.gridOptions.onRegisterApi = function(gridApi) {
            $scope.gridApi = gridApi;
        };
        $scope.gridOptions.totalItems = 0;

        function getPage() {
            return $http.post('/api/getVendorRouteList', requestExtraData).then(function(res){
                $scope.gridOptions.data = null;
                $scope["gridOptions"].data = res.data;
            },function(err) {
                $scope.gridOptions.data = null;
                console.log("NO REFRESH!!!!" + err);
            });
        }

        $scope.isDisabled = false;
        $scope.showVendorVerifyAlert = false;

        $scope.loading.busyPromise = getPage();

        $scope.digits = {};

        //initializing date picker
        $scope.dateDbA = moment();
        $scope.dateDbB = moment();

        $scope.optionsDbA = {
            callback: fromUpdated
        };
        $scope.optionsDbB = {
            callback: toUpdated
        };
        $scope.menuOpened = false;

        $scope.toggleMenu = function(event) {
            $scope.menuOpened = !($scope.menuOpened);
            event.stopPropagation();
        };

        $scope.closeThis = function() {
            if ($scope.menuOpened) {
                $scope.menuOpened = false;
            }
        };

        function openEditDialog() {
            //Using editVendor as a bindable Object in the modal.... cloning the original Vendor list
            //$scope.editVendor = angular.copy($scope.vendorList);
            ngDialog.open({
                template: '/vendor/vendorRouteMaintenance.html',
                showClose: true,
                scope: $scope
            });
        }

        $scope.addRowModal = function (row) {
            $scope.editRow = { isDefault: false };
            if (row != null) {
                $scope.editRow = findById($scope.gridOptions.data, row.entity.id);
            }
            openEditDialog();
        };

        $scope.deleteRow = function(row) {
            if (row != null) {
                var doDelete = $window.confirm("Are you sure?");
                if (doDelete) {
                    $scope.loading.busyPromise = $http.post('/api/deleteRouteVendor', row.entity).then(function (res) {
                        $scope.loading.busyPromise = getPage();
                    });
                }
            }
        };

        $scope.saveVendor = function(row) {
            $scope.editRow.dateModified = new Date();
            $scope.savingData.busyPromise = $http.post('/api/saveRouteVendor', $scope.editRow)
                .then(function(res) {
                    $scope.closeDialog();
                    $scope.loading.busyPromise = getPage();

                    // FRES-128 - add entry in the activity log
                    $scope.addActivityLog.busyPromise = addActivityLogEntry('tbl_vendor_route', 'Modified record [' +
                        $scope.editRow.vendorId + " - route : " + $scope.editRow.vendorPathRoute + "]");

                    // FRES-112
                    rebuidVendorRouteTable();

                }, function(err) {
                    console.log("error: " + err);
                    $scope.closeDialog();
                    $scope.loading.busyPromise = getPage();
                });
        };

        $scope.verifyVendor = function() {
            console.log("verifying");
            var row = {};
            row.vendorId = $scope.editRow.vendorId;
            //query for the combo
            $http.post('/api/getRouteVendor', row)
                .then(function(res) {
                    if (res.data[0] != null) {
                        existingRow = res.data[0];
                        if (existingRow.vendorId != null && existingRow.vendorId == row.vendorId) {
                            $scope.showVendorVerifyAlert = true;
                        }
                    } else {
                        $scope.isDisabled = true;
                    }
                }, function(err) {
                    console.log("Error checking Vendor Route : " + err);
                    $scope.closeDialog();
                });
        };

        $scope.editExistingRow = function() {
            console.log("editing");
            $scope.editRow = existingRow;
            $scope.showVendorVerifyAlert = false;
            $scope.isDisabled = true;
        };

        $scope.closeDialog = function(){
            ngDialog.close();
            $scope.showVendorVerifyAlert = false;
            $scope.isDisabled = false;
        };

        function findById(array, value) {
            for (var i = 0; i < array.length; i++) {
                if (array[i]['id'] === value) {
                    return array[i];
                }
            }
            return null;
        }

        function fromUpdated(date) {
            if (requestData.where == null) {
                requestData.where = {};
            }
            if (requestData.where.dateModified == null) {
                requestData.where.dateModified = {};
            }

            requestData.where.dateModified['$gt'] = date.startOf('day');
            $scope.fromDate = date.format("MM-DD-YYYY");
            getPage();
        }

        function toUpdated(date) {
            if (requestData.where == null) {
                requestData.where = {};
            }
            if (requestData.where.dateModified == null) {
                requestData.where.dateModified = {};
            }

            requestData.where.dateModified['$lt'] = date.endOf('day');
            $scope.toDate = date.format("MM-DD-YYYY");
            getPage();
        }

        // FRES-112
        // The function is called everytime a record of the tbl_vendor_route is modified
        // NOTE ! The function uses a dialog from the vendor page to notify errors or the sync completion
        function rebuidVendorRouteTable() {
            var delayInMilliseconds = 2500; //2.5 second

            // Delay the call to give time to the previous activity log to be stored

            setTimeout(function() {
                $http.post('/api/v1/rebuildVendorRouteAppTable', null)
                .then(function(res) {
                    console.log("Called the rebuild vendor route app tables API function - OK");

                    // FRES-128 - add entry in the activity log
                    $scope.addActivityLog.busyPromise = addActivityLogEntry('tbl_vendor_route_app', 're-done the sync');

                    ngDialog.open({
                        template: '/vendor/vendorConfirm.html',
                        showClose: true,
                        scope: $scope
                    });
                }, function(err) {
                    console.log("Error checking Vendor tables : " + err);
                    ngDialog.open({
                        template: '/vendor/vendorError.html',
                        showClose: true,
                        scope: $scope
                    });
                });

                $http.post('/api/v1/rebuildVendorRouteProductTable', null)
                    .then(function(res) {
                        console.log("Called the rebuild vendor route product tables API function - OK");

                        // FRES-128 - add entry in the activity log
                        $scope.addActivityLog.busyPromise = addActivityLogEntry('tbl_vendor_route_product', 're-done the sync');

                        ngDialog.open({
                            template: '/vendor/vendorConfirm.html',
                            showClose: true,
                            scope: $scope
                        });
                    }, function(err) {
                        console.log("Error checking Vendor tables : " + err);
                        ngDialog.open({
                            template: '/vendor/vendorError.html',
                            showClose: true,
                            scope: $scope
                        });
                    });
            }, delayInMilliseconds);
        }

        // FRES-128 - add entry to the ActivityLog table
        // Important ! Give at least a couple of seconds if you need to call this function back-to-back
        function addActivityLogEntry(name_table, desc)  {
            console.log("vendorRouteCtrl.js - addActivityLogEntry : " + name_table + " - " + desc);
            var record = {nameTable:"", description:"", dateModified:0};
            record.dateModified = new Date();
            record.nameTable = name_table;
            record.description = desc;

            return $http.post('/api/recordActivityLog', record).then(function (res) {
                console.log("log recorded");
            }, function (err) {
                console.log("error: " + err);
            });
        }
    }

]);